@@ -4,7 +4,7 @@
 
 use crate::{conn::Payload, Result};
 
-impl_api_ty!(Config => name: N);
+impl_api_ty!(Config => name);
 
 impl<'docker> Config<'docker> {
     impl_api_ep! { cfg: Config, resp
@@ -22,7 +22,7 @@ impl<'docker> Configs<'docker> {
     }
 }
 
-pub mod data {
+pub mod models {
     use crate::{
         api::{Driver, Labels, ObjectVersion},
         Error, Result,
@@ -85,17 +85,19 @@ pub mod data {
         }
 
         /// Set the templating driver of this config.
-        pub fn set_templating(&mut self, driver: Driver) {
+        pub fn set_templating(mut self, driver: Driver) -> Self {
             self.templating = driver;
+            self
         }
 
         /// Add a label to this config
-        pub fn add_label<K, V>(&mut self, key: K, val: V) -> Option<String>
+        pub fn add_label<K, V>(mut self, key: K, val: V) -> Self
         where
             K: Into<String>,
             V: Into<String>,
         {
-            self.labels.insert(key.into(), val.into())
+            self.labels.insert(key.into(), val.into());
+            self
         }
 
         pub fn serialize(&self) -> Result<String> {
@@ -131,7 +133,7 @@ pub mod data {
     }
 }
 
-pub use data::*;
+pub use models::*;
 
 pub mod opts {
     use crate::api::Filter;
