@@ -1,14 +1,14 @@
 //! Create and manage user-defined networks that containers can be attached to.
 
-pub mod data;
+pub mod models;
 pub mod opts;
 
-pub use data::*;
+pub use models::*;
 pub use opts::*;
 
 use crate::{conn::Payload, Result};
 
-impl_api_ty!(Network => id: I);
+impl_api_ty!(Network => id);
 
 impl<'docker> Network<'docker> {
     impl_api_ep! { net: Network, resp
