@@ -4,7 +4,7 @@ macro_rules! impl_vec_field {
             $(
                 #[doc= $docs]
             )*
-            pub fn [< $name  >]<[< $ty >], S>(&mut self, $name: $ty)-> &mut Self
+            pub fn [< $name  >]<[< $ty >], S>(mut self, $name: $ty)-> Self
             where
                 $ty: IntoIterator<Item = S>,
                 S: AsRef<str> + serde::Serialize
@@ -22,7 +22,7 @@ macro_rules! impl_field {
             $(
                 #[doc= $docs]
             )*
-            pub fn [< $name >](&mut self, $name: $ty)-> &mut Self
+            pub fn [< $name >](mut self, $name: $ty)-> Self
             {
                 self.params.insert($docker_name, serde_json::json!($name));
                 self
@@ -37,7 +37,7 @@ macro_rules! impl_str_field {
             $(
                 #[doc= $docs]
             )*
-            pub fn [< $name >]<[< $ty >]>(&mut self, $name: $ty)-> &mut Self
+            pub fn [< $name >]<[< $ty >]>(mut self, $name: $ty)-> Self
             where
                 $ty: AsRef<str> + serde::Serialize,
             {
@@ -54,7 +54,7 @@ macro_rules! impl_url_str_field {
             $(
                 #[doc= $docs]
             )*
-            pub fn [< $name >]<[< $ty >]>(&mut self, $name: $ty)-> &mut Self
+            pub fn [< $name >]<[< $ty >]>(mut self, $name: $ty)-> Self
             where
                 $ty: Into<String>,
             {
@@ -71,7 +71,7 @@ macro_rules! impl_url_field {
             $(
                 #[doc= $docs]
             )*
-            pub fn [< $name >](&mut self, $name: $ty)-> &mut Self {
+            pub fn [< $name >](mut self, $name: $ty)-> Self {
                 self.params.insert($docker_name, $name.to_string());
                 self
             }
@@ -85,7 +85,7 @@ macro_rules! impl_url_bool_field {
             $(
                 #[doc= $docs]
             )*
-            pub fn [< $name >](&mut self, $name: bool)-> &mut Self {
+            pub fn [< $name >](mut self, $name: bool)-> Self {
                 self.params.insert($docker_name, $name.to_string());
                 self
             }
@@ -100,7 +100,7 @@ macro_rules! impl_str_enum_field {
             $(
                 #[doc= $docs]
             )*
-            pub fn [< $name >](&mut self, $name: $ty)-> &mut Self
+            pub fn [< $name >](mut self, $name: $ty)-> Self
             {
                 self.params.insert($docker_name, serde_json::json!($name.as_ref()));
                 self
@@ -121,7 +121,7 @@ macro_rules! impl_map_field {
             $(
                 #[doc= $docs]
             )*
-            pub fn [< $name  >]<[< $ty >], K, V>(&mut self, $name: $ty)-> &mut Self
+            pub fn [< $name  >]<[< $ty >], K, V>(mut self, $name: $ty)-> Self
             where
                 $ty: IntoIterator<Item = (K, V)>,
                 K: AsRef<str> + serde::Serialize + Eq + std::hash::Hash,
@@ -222,23 +222,26 @@ macro_rules! calculated_doc {
 }
 
 macro_rules! impl_api_ty {
-    ($(#[doc = $docs:expr])* $name:ident => $name_field:ident : $name_field_tt:tt) => {
+    ($(#[doc = $docs:expr])* $name:ident => $name_field:ident) => {
         paste::item! {
+            pub type [< $name Id >] = String;
+            pub type [< $name IdRef >]<'a> = &'a str;
+
             calculated_doc!{
             #[doc = concat!("Interface for accessing and manipulating Docker ", stringify!($name), ".\n", $($docs,)* "\n", api_url!($name))]
             #[derive(Debug)]
             pub struct [< $name >]<'docker> {
                 docker: &'docker crate::Docker,
-                $name_field: String,
+                $name_field: [< $name Id >],
             }
             }
             impl<'docker> [< $name >]<'docker> {
                 // TODO: this is possible on nightly, figure out what to do
                 calculated_doc!{
                 #[doc = concat!("Exports an interface exposing operations against a ", stringify!($name), " instance.")]
-                pub fn new<$name_field_tt>(docker: &'docker crate::Docker, $name_field: $name_field_tt) -> Self
+                pub fn new<ID>(docker: &'docker crate::Docker, $name_field: ID) -> Self
                 where
-                    $name_field_tt: Into<String>,
+                    ID: Into<[< $name Id>]>,
                 {
                     [< $name >] {
                         docker,
@@ -249,7 +252,7 @@ macro_rules! impl_api_ty {
 
                 calculated_doc!{
                 #[doc = concat!("A getter for ", stringify!($name), " ", stringify!($name_field))]
-                pub fn $name_field(&self) -> &str {
+                pub fn $name_field(&self) -> [< $name IdRef >] {
                     &self.$name_field
                 }
                 }
@@ -276,9 +279,9 @@ macro_rules! impl_api_ty {
 
                 calculated_doc!{
                 #[doc = concat!("Returns a reference to a set of operations available to a specific ", stringify!($name), ".")]
-                pub fn get<$name_field_tt>(&self, $name_field: $name_field_tt) -> [< $name >]<'docker>
+                pub fn get<ID>(&self, $name_field: ID) -> [< $name >]<'docker>
                 where
-                    $name_field_tt: Into<String>,
+                    ID: Into<[< $name Id >]>,
                 {
                     [< $name >]::new(self.docker, $name_field)
                 }
@@ -294,13 +297,13 @@ macro_rules! impl_filter_func {
         $(
             #[doc = $doc]
         )*
-        pub fn filter<F>(&mut self, filters: F) -> &mut Self
+        pub fn filter<F>(mut self, filters: F) -> Self
         where
             F: IntoIterator<Item = $filter_ty>,
         {
             let mut param = std::collections::HashMap::new();
             for (key, val) in filters.into_iter().map(|f| f.query_key_val()) {
-                param.insert(key, val);
+                param.insert(key, vec![val]);
             }
             // structure is a a json encoded object mapping string keys to a list
             // of string values
@@ -536,13 +539,11 @@ macro_rules! impl_api_ep {
         pub fn logs(
             &self,
             opts: &crate::api::LogsOpts
-        ) -> impl futures_util::stream::Stream<Item = crate::Result<crate::conn::TtyChunk>> + Unpin + 'docker {
+        ) -> impl futures_util::Stream<Item = crate::Result<bytes::Bytes>> + Unpin + 'docker {
             let $it = self;
             let ep = crate::util::url::construct_ep($ep, opts.serialize());
 
-            let stream = Box::pin(self.docker.stream_get(ep));
-
-            Box::pin(crate::conn::tty::decode(stream))
+            Box::pin(self.docker.stream_get(ep))
         }
         }}
     };
