@@ -3,9 +3,9 @@
 use crate::{Error, Result};
 
 use futures_util::{
-    future::TryFutureExt,
     io::{AsyncRead, AsyncWrite},
-    stream::{self, Stream, StreamExt},
+    stream::{self, Stream},
+    StreamExt, TryFutureExt,
 };
 use hyper::{
     body::Bytes,
@@ -308,15 +308,6 @@ impl Transport {
         B: Into<Body>,
     {
         let ep = endpoint.as_ref();
-        let ep = format!(
-            "/{}{}{}",
-            crate::VERSION,
-            if !ep.starts_with('/') { "/" } else { "" },
-            ep
-        );
-
-        // As noted in [Versioning](https://docs.docker.com/engine/api/v1.41/#section/Versioning), all requests
-        // should be prefixed with the API version as the ones without will stop being supported in future releases
         let uri: hyper::Uri = match self {
             Transport::Tcp { host, .. } => format!("{}{}", host, ep)
                 .parse()
@@ -326,7 +317,7 @@ impl Transport {
                 .parse()
                 .map_err(Error::InvalidUri)?,
             #[cfg(unix)]
-            Transport::Unix { path, .. } => DomainUri::new(&path, &ep).into(),
+            Transport::Unix { path, .. } => DomainUri::new(&path, ep).into(),
         };
         let req = builder.method(method).uri(&uri);
         let mut req = req.header(header::HOST, "");
